searchData={"items":[{"type":"module","title":"Elxvips","doc":"Documentation for `Elxvips`.","ref":"Elxvips.html"},{"type":"function","title":"Elxvips.avif/2","doc":"Will save the ImageFile in avif(AV1) format to a specified path. Accepts quality and strip options.\nBy default quality is set to 100","ref":"Elxvips.html#avif/2"},{"type":"function","title":"Examples - Elxvips.avif/2","doc":"iex> import Elxvips\n    iex>\n    iex> from_file( \"/path/input.jpg\" )\n    iex> |> avif( quality: 72 )\n    iex  |> to_file( \"/path/output.avif\" )\n    { :ok, %ImageFile{} }","ref":"Elxvips.html#avif/2-examples"},{"type":"function","title":"Elxvips.background/2","doc":"Sets the background of the image in case there is a transparent background.\nAccepts a empty list, or a list of length 2 or 3.","ref":"Elxvips.html#background/2"},{"type":"function","title":"Examples - Elxvips.background/2","doc":"iex> import Elxvips\n    iex>\n    iex> from_file( \"test/input.png\" )\n    iex  |> jpg()\n    iex> |> background( [ 255, 0, 0 ] ) # red background\n    iex  |> to_file( \"test/output.jpg\" )\n    {:ok, %ImageBytes{}}","ref":"Elxvips.html#background/2-examples"},{"type":"function","title":"Elxvips.check_opts/1","doc":"","ref":"Elxvips.html#check_opts/1"},{"type":"function","title":"Elxvips.from_bytes/1","doc":"Will create an %ImageByte{} struct from bitstring or byte list. This struct will be used for further processing.","ref":"Elxvips.html#from_bytes/1"},{"type":"function","title":"Examples - Elxvips.from_bytes/1","doc":"iex> import Elxvips\n    iex>\n    iex> file = File.open!( \"/path/input.png\" )\n    iex> bytes = IO.binread( file, :all )\n    iex> from_bytes( bytes )\n    %ImageBytes{}","ref":"Elxvips.html#from_bytes/1-examples"},{"type":"function","title":"Elxvips.from_file/1","doc":"Will create an %ImageFile{} struct from path. This struct will be used for further processing.","ref":"Elxvips.html#from_file/1"},{"type":"function","title":"Examples - Elxvips.from_file/1","doc":"iex> import Elxvips\n    iex>\n    iex> from_file( \"/path/input.png\" )\n    %ImageFile{}","ref":"Elxvips.html#from_file/1-examples"},{"type":"function","title":"Elxvips.from_pdf/2","doc":"Will create an %ImageFile{} struct from a pdf path. This struct will be used for further processing.\nAccepts the following options:\n* `:page` - page number to extract from pdf, default is 0\n* `:n` - number of pages to extract from pdf, default is 1","ref":"Elxvips.html#from_pdf/2"},{"type":"function","title":"Examples - Elxvips.from_pdf/2","doc":"iex> import Elxvips\n    iex>\n    iex> from_pdf( \"/path/input.pdf\", page: 0, n: 2 )\n    %ImageFile{}","ref":"Elxvips.html#from_pdf/2-examples"},{"type":"function","title":"Elxvips.from_pdf_bytes/1","doc":"Will create an %ImageByte{} struct from pdf bitstring or byte list. This struct will be used for further processing.\nAccepts the following options:\n* `:page` - page number to extract from pdf, default is 0\n* `:n` - number of pages to extract from pdf, default is 1","ref":"Elxvips.html#from_pdf_bytes/1"},{"type":"function","title":"Examples - Elxvips.from_pdf_bytes/1","doc":"iex> import Elxvips\n    iex>\n    iex> file = File.open!( \"/path/input.pdf\" )\n    iex> bytes = IO.binread( file, :all )\n    iex> from_pdf_bytes( bytes, page: 0, n: 2 )\n    %ImageBytes{}","ref":"Elxvips.html#from_pdf_bytes/1-examples"},{"type":"function","title":"Elxvips.from_pdf_bytes/2","doc":"","ref":"Elxvips.html#from_pdf_bytes/2"},{"type":"function","title":"Elxvips.get_image_format/1","doc":"Returns format of the specified image, works with a image path or bytes.","ref":"Elxvips.html#get_image_format/1"},{"type":"function","title":"Examples - Elxvips.get_image_format/1","doc":"iex> import Elxvips\n    iex>\n    iex> from_file( \"test/input.png\" )\n    iex> |> get_image_format()\n    {:ok, :png}","ref":"Elxvips.html#get_image_format/1-examples"},{"type":"function","title":"Elxvips.get_image_sizes/1","doc":"Returns dimensions of the specified image, works with a image path or bytes.","ref":"Elxvips.html#get_image_sizes/1"},{"type":"function","title":"Examples - Elxvips.get_image_sizes/1","doc":"iex> import Elxvips\n    iex>\n    iex> from_file( \"test/input.png\" )\n    iex> |> get_image_sizes()\n    {:ok, [640, 486]}","ref":"Elxvips.html#get_image_sizes/1-examples"},{"type":"function","title":"Elxvips.jpg/2","doc":"Will save the ImageFile in jpeg format to a specified path. Accepts quality and strip options.\nBy default quality is set to 90 and strip to true.","ref":"Elxvips.html#jpg/2"},{"type":"function","title":"Examples - Elxvips.jpg/2","doc":"iex> import Elxvips\n    iex>\n    iex> from_file( \"/path/input.png\" )\n    iex> |> jpg( strip: true, quality: 72 )\n    iex  |> to_file( \"/path/output.jpg\" )\n    { :ok, %ImageFile{} }","ref":"Elxvips.html#jpg/2-examples"},{"type":"function","title":"Elxvips.png/2","doc":"Will save the ImageFile in png format to a specified path. Accepts quality, compression(0-9) and strip options.\nBy default quality is set to 100, compression to 6, strip to true. Decreasing compression will speed up image saving.","ref":"Elxvips.html#png/2"},{"type":"function","title":"Examples - Elxvips.png/2","doc":"iex> import Elxvips\n    iex>\n    iex> from_file( \"/path/input.jpg\" )\n    iex> |> png( strip: true, quality: 72 )\n    iex  |> to_file( \"/path/output.png\" )\n    { :ok, %ImageFile{} }","ref":"Elxvips.html#png/2-examples"},{"type":"function","title":"Elxvips.resize/2","doc":"Applies resize options to an %ImageFile{} or %ImageBytes{}, accepts :width, :height and :type (not implemented yet).\nIf no width or height is specified dimensions are calculated from the input image.\nEmpty resize( no :width and no :height) will produce an image with the dimensions as the original one.","ref":"Elxvips.html#resize/2"},{"type":"function","title":"Examples - Elxvips.resize/2","doc":"iex> import Elxvips\n    iex>\n    iex> from_file( \"test/input.png\" )\n    iex> |> resize( width: 300 )\n    iex  |> to_bytes()\n    {:ok, %ImageBytes{}}","ref":"Elxvips.html#resize/2-examples"},{"type":"function","title":"Elxvips.set_concurrency/1","doc":"","ref":"Elxvips.html#set_concurrency/1"},{"type":"function","title":"Elxvips.svg/2","doc":"Will save the ImageFile in SVG format to a specified path. Accepts no options.\nHighly discouraged to use this function, since it will embed the image in the svg file.\nIn case an svg is used as input, it will just copy the file.","ref":"Elxvips.html#svg/2"},{"type":"function","title":"Examples - Elxvips.svg/2","doc":"iex> import Elxvips\n    iex>\n    iex> from_file( \"/path/input.jpg\" )\n    iex> |> svg()\n    iex  |> to_file( \"/path/output.svg\" )\n    { :ok, %ImageFile{} }","ref":"Elxvips.html#svg/2-examples"},{"type":"function","title":"Elxvips.to_bytes/1","doc":"Will create a new %ImageBytes{} struct containing all the changes.","ref":"Elxvips.html#to_bytes/1"},{"type":"function","title":"Examples - Elxvips.to_bytes/1","doc":"iex> import Elxvips\n    iex>\n    iex> from_file( \"test/input.png\" )\n    iex> |> png()\n    iex> |> to_bytes()\n    {:ok, %ImageBytes{}}","ref":"Elxvips.html#to_bytes/1-examples"},{"type":"function","title":"Elxvips.to_file/2","doc":"Will save the image to a path on disk and return a new %ImageFile{} from the new path.","ref":"Elxvips.html#to_file/2"},{"type":"function","title":"Examples - Elxvips.to_file/2","doc":"iex> import Elxvips\n    iex>\n    iex> from_file( \"test/input.png\" )\n    iex> |> png()\n    iex> |> to_file( \"test/outping.png\" )\n    {:ok, %ImageBytes{}}","ref":"Elxvips.html#to_file/2-examples"},{"type":"function","title":"Elxvips.webp/2","doc":"Will save the ImageFile in webp format to a specified path. Accepts quality and strip options.\nBy default quality is set to 100, and strip to true.","ref":"Elxvips.html#webp/2"},{"type":"function","title":"Examples - Elxvips.webp/2","doc":"iex> import Elxvips\n    iex>\n    iex> from_file( \"/path/input.jpg\" )\n    iex> |> webp( strip: true, quality: 72 )\n    iex  |> to_file( \"/path/output.webp\" )\n    { :ok, %ImageFile{} }","ref":"Elxvips.html#webp/2-examples"},{"type":"module","title":"Elxvips.ImageBytes","doc":"","ref":"Elxvips.ImageBytes.html"},{"type":"module","title":"Elxvips.ImageFile","doc":"","ref":"Elxvips.ImageFile.html"},{"type":"module","title":"Elxvips.Native","doc":"","ref":"Elxvips.Native.html"},{"type":"function","title":"Elxvips.Native.set_concurrency/1","doc":"","ref":"Elxvips.Native.html#set_concurrency/1"},{"type":"function","title":"Elxvips.Native.vips_get_image_bytes_format/1","doc":"","ref":"Elxvips.Native.html#vips_get_image_bytes_format/1"},{"type":"function","title":"Elxvips.Native.vips_get_image_bytes_sizes/1","doc":"","ref":"Elxvips.Native.html#vips_get_image_bytes_sizes/1"},{"type":"function","title":"Elxvips.Native.vips_get_image_file_format/1","doc":"","ref":"Elxvips.Native.html#vips_get_image_file_format/1"},{"type":"function","title":"Elxvips.Native.vips_get_image_sizes/1","doc":"","ref":"Elxvips.Native.html#vips_get_image_sizes/1"},{"type":"function","title":"Elxvips.Native.vips_process_bytes_to_bytes/1","doc":"","ref":"Elxvips.Native.html#vips_process_bytes_to_bytes/1"},{"type":"function","title":"Elxvips.Native.vips_process_bytes_to_file/1","doc":"","ref":"Elxvips.Native.html#vips_process_bytes_to_file/1"},{"type":"function","title":"Elxvips.Native.vips_process_file_to_bytes/1","doc":"","ref":"Elxvips.Native.html#vips_process_file_to_bytes/1"},{"type":"function","title":"Elxvips.Native.vips_process_file_to_file/1","doc":"","ref":"Elxvips.Native.html#vips_process_file_to_file/1"},{"type":"module","title":"Elxvips.ResizeOptions","doc":"","ref":"Elxvips.ResizeOptions.html"},{"type":"module","title":"Elxvips.SaveOptions","doc":"","ref":"Elxvips.SaveOptions.html"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}